@@ -1,7 +1,10 @@
+#if !defined (__GIO_GIO_H_INSIDE__) && !defined (GIO_COMPILATION)
+#error "Only <gio/gio.h> can be included directly."
+#endif
+
 #ifndef __G_NATIVE_VOLUME_MONITOR_H__
 #define __G_NATIVE_VOLUME_MONITOR_H__
 
-#include <glib-object.h>
 #include <gio/gvolumemonitor.h>
 
 G_BEGIN_DECLS
@@ -14,26 +17,24 @@ G_BEGIN_DECLS
 
 #define G_NATIVE_VOLUME_MONITOR_EXTENSION_POINT_NAME "gio-native-volume-monitor"
 
-typedef struct _GNativeVolumeMonitor GNativeVolumeMonitor;
+typedef struct _GNativeVolumeMonitor      GNativeVolumeMonitor;
 typedef struct _GNativeVolumeMonitorClass GNativeVolumeMonitorClass;
 
-struct _GNativeVolumeMonitor {
+struct _GNativeVolumeMonitor
+{
   GVolumeMonitor parent_instance;
 };
 
-struct _GNativeVolumeMonitorClass {
+struct _GNativeVolumeMonitorClass
+{
   GVolumeMonitorClass parent_class;
 
-  int priority;
-  char *name;
-
-  GMount * (*get_mount_for_mount_path) (const char *mount_path,
-					GCancellable *cancellable);
+  GMount * (* get_mount_for_mount_path) (const char   *mount_path,
+                                         GCancellable *cancellable);
 };
 
 GType g_native_volume_monitor_get_type (void) G_GNUC_CONST;
 
-
 G_END_DECLS
 
 #endif /* __G_NATIVE_VOLUME_MONITOR_H__ */
